#!/bin/sh
#
# Creates our user accounts, expires the password and adds the user to the
# sudo and adm groups.

set -e

USERS="jampen rothe forster deck"
GROUPS="sudo adm"

create_user() {
	USER="${1}"

	# add user account with disabled password
	adduser --disabled-password --gecos ",,," ${USER}

	# set empty password
	usermod -p "" ${USER}

	# set last password change to 01.01.1970
	# resulting in immediate password change request on login
	chage -d 0 ${USER}
}

add_user_to_group() {
	USER="${1}"
	GROUP="${2}"

	id ${USER} | grep ${GROUP} > /dev/null 2>&1 || (adduser ${USER} ${GROUP})
}

for USER in ${USERS}
do
	# create user if it does not yet exist
	id -u ${USER} > /dev/null 2>&1 || create_user ${USER}

	# make sure user belongs to listed groups
	for GROUP in ${GROUPS}
	do
		add_user_to_group ${USER} ${GROUP}
	done
done
